MediaWiki

Jump to content

# MediaWiki is a collaboration and documentation platform brought to you by a vibrant community.

From mediawiki.org

## MediaWiki is a collaboration and documentation platform brought to you by a vibrant community.

Photo of participants of the Wikimedia Hackathon 2024

The MediaWiki software is used by tens of thousands of websites and thousands of companies and organisations. It powers Wikipedia and also this website. MediaWiki helps you collect and organise knowledge and make it available to people. It's powerful, multilingual, free and open, extensible, customisable, reliable, and free of charge. Find out more and if MediaWiki is right for you.

### Set up and run MediaWiki

- Download, install and configure MediaWiki
- Add functionality by installing extensions
- Problems? See errors and symptoms and FAQ
- Don't own a server? Find hosting services
- Get professional development and consulting
- Join MediaWiki Stakeholders user group

### Edit and use MediaWiki

- Learn how to navigate
- Learn how to edit a page
- Learn more about reading, editing, and personal customisation

### Develop and extend code

- Read the MediaWiki developer documentation
- Visit the Wikimedia Developer Portal

### Get help and contribute

- Cannot find the answer to a problem with MediaWiki? Ask the support desk!
- Get involved as a translator, designer, documentation writer, tester, tech ambassador, or developer
- Report wrong software behaviour or a feature proposal

### News

2024-06-28
  MediaWiki 1.40.x versions are now end of life.
2024-06-27
  Maintenance release: 1.39.8 / 1.40.4 / 1.41.2 / 1.42.1
  MediaWiki 1.42.0 is now available.
2024-11-04 to 2024-11-06
  MediaWiki Users and Developers Conference Fall 2024 in Vienna, Austria.
2024-05-03 to 2024-05-05
  Wikimedia Hackathon 2024 in Tallinn, Estonia.
2024-04-17 to 2024-04-19
  MediaWiki Users and Developers Conference Spring 2024 in Portland, OR (USA). (View livestream)
2024-03-28
  MediaWiki 1.39.7, 1.40.3 and 1.41.1 security releases are now available.

More news

Languages:
English • Afrikaans • العربية • asturianu • беларуская • беларуская (тарашкевіца) • български • বাংলা • bosanski • català • کوردی • čeština • dansk • Deutsch • Ελληνικά • español • فارسی • suomi • français • galego • ગુજરાતી • עברית • हिन्दी • hrvatski • magyar • հայերեն • Bahasa Indonesia • italiano • 日本語 • Jawa • қазақша • 한국어 • Bahasa Melayu • Mirandés • Nederlands • polski • português • português do Brasil • română • русский • sardu • සිංහල • slovenčina • slovenščina • Soomaaliga • shqip • српски / srpski • svenska • ไทย • Türkçe • українська • Tiếng Việt • 粵語 • 中文

Retrieved from "https://www.mediawiki.org/w/index.php?title=MediaWiki&oldid=6287429"
Hidden category:

- Languages pages